flaat-get-userinfo.py
=====================

Synopsis
--------

:program:`get_userinfo` [options]

Description
-----------

:program:`get_userinfo` is a simple tool to gather all info based on a given OIDC Access Token.

Options
-------

   .. argparse::
      :filename: get_userinfo.py
      :func: parseOptions
      :prog: get_userinfo.py

Files
-----

TBD.

See Also
--------

TBD.

Reporting Bugs
--------------

Bugs are managed at `github <https://github.com/indigo-dc/flaat>`__

